@@ -46,11 +46,16 @@ xstrfind (xstr str, xstr find, xuint first)
     return -1;
 }
 
-xstr
+XString*
 xitostr (xuint value)
 {
+  XString* text;
+
+  text = x_string_new ();
   sprintf (xtmp, "%d", value);
-  return xtmp;
+  x_string_set_str (text, xtmp);
+  
+  return text;
 }
 
 xstr
@@ -88,11 +93,12 @@ xa_lang_init ()
 		   "cstring", "str_a",
 		   "cstring", "str_b",
 		   NULL);
-
-  xa_api_reg_fnct ("itostr", xitostr, "cstring",
+  */
+  xa_api_reg_fnct ("itostr", xitostr, "string",
 		   "uint", "value",
 		   NULL);
 
+  /*
   xa_api_reg_fnct ("ftostr", xftostr, "cstring",
 		   "float", "value",
 		   NULL);	  
