@@ -131,12 +131,12 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 22 "langbasic_yacc.y"
+#line 22 "parser/basiclike/langbasic_yacc.y"
 
 
 #include <xltype.h>
 #include <xlexpr.h>
-#include <xllangbasic.h>
+#include <parser/basiclike/xllangbasic.h>
 #include <xllang.h>
 
 #ifndef YYDEBUG
@@ -159,7 +159,7 @@
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 35 "langbasic_yacc.y"
+#line 35 "parser/basiclike/langbasic_yacc.y"
 typedef union YYSTYPE {
   XLExpr*     expr;
   XLTypeType  xtype;
@@ -1205,87 +1205,87 @@ yyreduce:
   switch (yyn)
     {
         case 4:
-#line 71 "langbasic_yacc.y"
+#line 71 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_decl_add (yyvsp[0].expr); }
     break;
 
   case 5:
-#line 72 "langbasic_yacc.y"
+#line 72 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_decl_add (yyvsp[0].expr); }
     break;
 
   case 6:
-#line 73 "langbasic_yacc.y"
+#line 73 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_decl_add (yyvsp[0].expr); }
     break;
 
   case 7:
-#line 74 "langbasic_yacc.y"
+#line 74 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_basic_error ("Expecting a declaration"); }
     break;
 
   case 9:
-#line 83 "langbasic_yacc.y"
+#line 83 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_class_add (yyvsp[0].expr); }
     break;
 
   case 10:
-#line 86 "langbasic_yacc.y"
+#line 86 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = yyvsp[0].expr; }
     break;
 
   case 11:
-#line 87 "langbasic_yacc.y"
+#line 87 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = yyvsp[0].expr; }
     break;
 
   case 12:
-#line 88 "langbasic_yacc.y"
+#line 88 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_basic_error ("Expecting a class field (property or method"); }
     break;
 
   case 13:
-#line 93 "langbasic_yacc.y"
+#line 93 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("prop", yyvsp[-2].expr, yyvsp[-1].expr); }
     break;
 
   case 14:
-#line 94 "langbasic_yacc.y"
+#line 94 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_basic_error ("Expecting an identifier\n"); }
     break;
 
   case 15:
-#line 99 "langbasic_yacc.y"
+#line 99 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_method_create (yyvsp[-1].expr, yyvsp[0].expr);  }
     break;
 
   case 16:
-#line 102 "langbasic_yacc.y"
+#line 102 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_method_finish (yyvsp[0].expr); }
     break;
 
   case 17:
-#line 107 "langbasic_yacc.y"
+#line 107 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_class_create (yyvsp[0].expr, NULL); }
     break;
 
   case 18:
-#line 109 "langbasic_yacc.y"
+#line 109 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_class_finish (); }
     break;
 
   case 19:
-#line 111 "langbasic_yacc.y"
+#line 111 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_basic_error ("Missing an identifier"); }
     break;
 
   case 20:
-#line 116 "langbasic_yacc.y"
+#line 116 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("global", yyvsp[0].expr, yyvsp[-2].expr); }
     break;
 
   case 21:
-#line 118 "langbasic_yacc.y"
+#line 118 "parser/basiclike/langbasic_yacc.y"
     {
       yyvsp[-6].expr->type->array_type = XL_TYPE_ARRAY_TYPE_DYNAMIC;
       yyvsp[-6].expr->type->array_size = 0;
@@ -1294,7 +1294,7 @@ yyreduce:
     break;
 
   case 22:
-#line 124 "langbasic_yacc.y"
+#line 124 "parser/basiclike/langbasic_yacc.y"
     {
       yyvsp[0].expr->type->array_type = XL_TYPE_ARRAY_TYPE_FIXED;
       yyvsp[0].expr->type->array_size = yyvsp[-3].val_int;
@@ -1303,12 +1303,12 @@ yyreduce:
     break;
 
   case 23:
-#line 154 "langbasic_yacc.y"
+#line 154 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_fnct_add_param (yyvsp[0].expr, yyvsp[-2].expr); }
     break;
 
   case 24:
-#line 156 "langbasic_yacc.y"
+#line 156 "parser/basiclike/langbasic_yacc.y"
     {
       yyvsp[0].expr->type->array_type = XL_TYPE_ARRAY_TYPE_DYNAMIC;
       yyvsp[0].expr->type->array_size = 0;
@@ -1317,7 +1317,7 @@ yyreduce:
     break;
 
   case 25:
-#line 162 "langbasic_yacc.y"
+#line 162 "parser/basiclike/langbasic_yacc.y"
     {
       yyvsp[0].expr->type->array_type = XL_TYPE_ARRAY_TYPE_FIXED;
       yyvsp[0].expr->type->array_size = yyvsp[-3].val_int;
@@ -1326,259 +1326,259 @@ yyreduce:
     break;
 
   case 29:
-#line 177 "langbasic_yacc.y"
+#line 177 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_fnct_create (NULL, yyvsp[0].expr);  }
     break;
 
   case 30:
-#line 182 "langbasic_yacc.y"
+#line 182 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_fnct_set_type (yyvsp[-3].expr);
     yyval.expr = xl_lang_fnct_finish (yyvsp[-2].expr); 
   }
     break;
 
   case 31:
-#line 187 "langbasic_yacc.y"
+#line 187 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_fnct_create (xl_lang_type_create (XL_TYPE_TYPE_VOID, XL_TYPE_ARRAY_TYPE_NONE, 0, NULL), yyvsp[0].expr);  }
     break;
 
   case 32:
-#line 191 "langbasic_yacc.y"
+#line 191 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_fnct_finish (yyvsp[-2].expr); }
     break;
 
   case 33:
-#line 199 "langbasic_yacc.y"
+#line 199 "parser/basiclike/langbasic_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_VOID;    }
     break;
 
   case 34:
-#line 200 "langbasic_yacc.y"
+#line 200 "parser/basiclike/langbasic_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_CHAR;    }
     break;
 
   case 35:
-#line 201 "langbasic_yacc.y"
+#line 201 "parser/basiclike/langbasic_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_UCHAR;   }
     break;
 
   case 36:
-#line 202 "langbasic_yacc.y"
+#line 202 "parser/basiclike/langbasic_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_SHORT;   }
     break;
 
   case 37:
-#line 203 "langbasic_yacc.y"
+#line 203 "parser/basiclike/langbasic_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_USHORT;  }
     break;
 
   case 38:
-#line 204 "langbasic_yacc.y"
+#line 204 "parser/basiclike/langbasic_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_INT;     }
     break;
 
   case 39:
-#line 205 "langbasic_yacc.y"
+#line 205 "parser/basiclike/langbasic_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_UINT;    }
     break;
 
   case 40:
-#line 206 "langbasic_yacc.y"
+#line 206 "parser/basiclike/langbasic_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_STRING;  }
     break;
 
   case 41:
-#line 207 "langbasic_yacc.y"
+#line 207 "parser/basiclike/langbasic_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_FLOAT;   }
     break;
 
   case 42:
-#line 208 "langbasic_yacc.y"
+#line 208 "parser/basiclike/langbasic_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_DOUBLE;  }
     break;
 
   case 43:
-#line 212 "langbasic_yacc.y"
+#line 212 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_type_create (yyvsp[0].xtype, XL_TYPE_ARRAY_TYPE_NONE, 0, NULL); }
     break;
 
   case 44:
-#line 213 "langbasic_yacc.y"
+#line 213 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_expr_new (); }
     break;
 
   case 45:
-#line 214 "langbasic_yacc.y"
+#line 214 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_expr_new (); }
     break;
 
   case 46:
-#line 219 "langbasic_yacc.y"
+#line 219 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr =  xl_expr_new_identifier (yyvsp[0].identifier); }
     break;
 
   case 47:
-#line 223 "langbasic_yacc.y"
+#line 223 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_data_string_create (yyvsp[0].val_string);   }
     break;
 
   case 48:
-#line 224 "langbasic_yacc.y"
+#line 224 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_data_integer_create (yyvsp[0].val_int);  }
     break;
 
   case 49:
-#line 225 "langbasic_yacc.y"
+#line 225 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_data_float_create (yyvsp[0].val_float);    }
     break;
 
   case 50:
-#line 226 "langbasic_yacc.y"
+#line 226 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_data_bool_create (TRUE);   }
     break;
 
   case 51:
-#line 227 "langbasic_yacc.y"
+#line 227 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_data_bool_create (FALSE);  }
     break;
 
   case 52:
-#line 235 "langbasic_yacc.y"
+#line 235 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = yyvsp[0].expr; }
     break;
 
   case 53:
-#line 236 "langbasic_yacc.y"
+#line 236 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = yyvsp[0].expr; }
     break;
 
   case 54:
-#line 237 "langbasic_yacc.y"
+#line 237 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = yyvsp[0].expr; }
     break;
 
   case 55:
-#line 238 "langbasic_yacc.y"
+#line 238 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = yyvsp[0].expr; }
     break;
 
   case 56:
-#line 239 "langbasic_yacc.y"
+#line 239 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("+", yyvsp[-2].expr, yyvsp[0].expr); }
     break;
 
   case 57:
-#line 240 "langbasic_yacc.y"
+#line 240 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("*", yyvsp[-2].expr, yyvsp[0].expr); }
     break;
 
   case 58:
-#line 241 "langbasic_yacc.y"
+#line 241 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("-", yyvsp[-2].expr, yyvsp[0].expr); }
     break;
 
   case 59:
-#line 242 "langbasic_yacc.y"
+#line 242 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("/", yyvsp[-2].expr, yyvsp[0].expr); }
     break;
 
   case 60:
-#line 243 "langbasic_yacc.y"
+#line 243 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("<=", yyvsp[-3].expr, yyvsp[0].expr); }
     break;
 
   case 61:
-#line 244 "langbasic_yacc.y"
+#line 244 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 (">=", yyvsp[-3].expr, yyvsp[0].expr); }
     break;
 
   case 62:
-#line 245 "langbasic_yacc.y"
+#line 245 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("<", yyvsp[-2].expr, yyvsp[0].expr); }
     break;
 
   case 63:
-#line 246 "langbasic_yacc.y"
+#line 246 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 (">", yyvsp[-2].expr, yyvsp[0].expr); }
     break;
 
   case 64:
-#line 247 "langbasic_yacc.y"
+#line 247 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("==", yyvsp[-3].expr, yyvsp[0].expr); }
     break;
 
   case 65:
-#line 248 "langbasic_yacc.y"
+#line 248 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("<>", yyvsp[-3].expr, yyvsp[0].expr); }
     break;
 
   case 66:
-#line 252 "langbasic_yacc.y"
+#line 252 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("[]", yyvsp[-3].expr, yyvsp[-1].expr); }
     break;
 
   case 68:
-#line 257 "langbasic_yacc.y"
+#line 257 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_call_add (yyvsp[0].expr); }
     break;
 
   case 69:
-#line 258 "langbasic_yacc.y"
+#line 258 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_call_add (yyvsp[0].expr); }
     break;
 
   case 72:
-#line 273 "langbasic_yacc.y"
+#line 273 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_block_add (yyvsp[0].expr); }
     break;
 
   case 73:
-#line 274 "langbasic_yacc.y"
+#line 274 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_block_add (yyvsp[0].expr); }
     break;
 
   case 74:
-#line 275 "langbasic_yacc.y"
+#line 275 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_block_add (yyvsp[0].expr); }
     break;
 
   case 75:
-#line 283 "langbasic_yacc.y"
+#line 283 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_block_begin (); }
     break;
 
   case 76:
-#line 285 "langbasic_yacc.y"
+#line 285 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_block_end (); }
     break;
 
   case 77:
-#line 295 "langbasic_yacc.y"
+#line 295 "parser/basiclike/langbasic_yacc.y"
     { xl_lang_call_begin (x_string_get_str (yyvsp[0].expr->identifier)); }
     break;
 
   case 78:
-#line 297 "langbasic_yacc.y"
+#line 297 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_call_end (); }
     break;
 
   case 79:
-#line 301 "langbasic_yacc.y"
+#line 301 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("=", yyvsp[-2].expr, yyvsp[0].expr); }
     break;
 
   case 80:
-#line 334 "langbasic_yacc.y"
+#line 334 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = NULL; }
     break;
 
   case 81:
-#line 335 "langbasic_yacc.y"
+#line 335 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = yyvsp[0].expr; }
     break;
 
   case 82:
-#line 344 "langbasic_yacc.y"
+#line 344 "parser/basiclike/langbasic_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("if", yyvsp[-6].expr, yyvsp[-3].expr); }
     break;
 
@@ -1792,7 +1792,7 @@ yyreturn:
 }
 
 
-#line 347 "langbasic_yacc.y"
+#line 347 "parser/basiclike/langbasic_yacc.y"
 
 
 
