@@ -125,12 +125,12 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 22 "langlisp_yacc.y"
+#line 22 "parser/lisplike/langlisp_yacc.y"
 
 
 #include <xltype.h>
 #include <xlexpr.h>
-#include <xllangc.h>
+#include <parser/clike/xllangc.h>
 
 
 #ifndef YYDEBUG
@@ -176,7 +176,7 @@ xuint lisp_line = 1;
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 58 "langlisp_yacc.y"
+#line 58 "parser/lisplike/langlisp_yacc.y"
 typedef union YYSTYPE {
   XLExpr*     expr;
   XLTypeType  xtype;
@@ -1204,42 +1204,42 @@ yyreduce:
   switch (yyn)
     {
         case 4:
-#line 94 "langlisp_yacc.y"
+#line 94 "parser/lisplike/langlisp_yacc.y"
     { xl_lang_decl_add (yyvsp[0].expr); }
     break;
 
   case 5:
-#line 95 "langlisp_yacc.y"
+#line 95 "parser/lisplike/langlisp_yacc.y"
     { xl_lang_decl_add (yyvsp[0].expr); }
     break;
 
   case 6:
-#line 96 "langlisp_yacc.y"
+#line 96 "parser/lisplike/langlisp_yacc.y"
     { xl_lang_decl_add (yyvsp[0].expr); }
     break;
 
   case 7:
-#line 97 "langlisp_yacc.y"
+#line 97 "parser/lisplike/langlisp_yacc.y"
     { xl_lang_lisp_error ("Expecting a declaration"); }
     break;
 
   case 8:
-#line 130 "langlisp_yacc.y"
+#line 130 "parser/lisplike/langlisp_yacc.y"
     { xl_lang_class_create (yyvsp[0].expr, NULL); }
     break;
 
   case 9:
-#line 132 "langlisp_yacc.y"
+#line 132 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_class_finish (); }
     break;
 
   case 11:
-#line 138 "langlisp_yacc.y"
+#line 138 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("global", yyvsp[-2].expr, yyvsp[-1].expr); }
     break;
 
   case 12:
-#line 140 "langlisp_yacc.y"
+#line 140 "parser/lisplike/langlisp_yacc.y"
     {
       yyvsp[-4].expr->type->array_type = XL_TYPE_ARRAY_TYPE_DYNAMIC;
       yyvsp[-4].expr->type->array_size = 0;
@@ -1248,7 +1248,7 @@ yyreduce:
     break;
 
   case 13:
-#line 146 "langlisp_yacc.y"
+#line 146 "parser/lisplike/langlisp_yacc.y"
     {
       yyvsp[-5].expr->type->array_type = XL_TYPE_ARRAY_TYPE_FIXED;
       yyvsp[-5].expr->type->array_size = yyvsp[-3].val_int;
@@ -1257,12 +1257,12 @@ yyreduce:
     break;
 
   case 14:
-#line 172 "langlisp_yacc.y"
+#line 172 "parser/lisplike/langlisp_yacc.y"
     { xl_lang_fnct_add_param (yyvsp[-1].expr, yyvsp[0].expr); }
     break;
 
   case 15:
-#line 174 "langlisp_yacc.y"
+#line 174 "parser/lisplike/langlisp_yacc.y"
     {
       yyvsp[-3].expr->type->array_type = XL_TYPE_ARRAY_TYPE_DYNAMIC;
       yyvsp[-3].expr->type->array_size = 0;
@@ -1271,7 +1271,7 @@ yyreduce:
     break;
 
   case 16:
-#line 180 "langlisp_yacc.y"
+#line 180 "parser/lisplike/langlisp_yacc.y"
     {
       yyvsp[-4].expr->type->array_type = XL_TYPE_ARRAY_TYPE_FIXED;
       yyvsp[-4].expr->type->array_size = yyvsp[-2].val_int;
@@ -1280,257 +1280,257 @@ yyreduce:
     break;
 
   case 20:
-#line 195 "langlisp_yacc.y"
+#line 195 "parser/lisplike/langlisp_yacc.y"
     { xl_lang_fnct_create (yyvsp[-1].expr, yyvsp[0].expr);  }
     break;
 
   case 21:
-#line 199 "langlisp_yacc.y"
+#line 199 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_fnct_finish (yyvsp[-1].expr); }
     break;
 
   case 22:
-#line 207 "langlisp_yacc.y"
+#line 207 "parser/lisplike/langlisp_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_VOID;    }
     break;
 
   case 23:
-#line 208 "langlisp_yacc.y"
+#line 208 "parser/lisplike/langlisp_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_CHAR;    }
     break;
 
   case 24:
-#line 209 "langlisp_yacc.y"
+#line 209 "parser/lisplike/langlisp_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_UCHAR;   }
     break;
 
   case 25:
-#line 210 "langlisp_yacc.y"
+#line 210 "parser/lisplike/langlisp_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_SHORT;   }
     break;
 
   case 26:
-#line 211 "langlisp_yacc.y"
+#line 211 "parser/lisplike/langlisp_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_USHORT;  }
     break;
 
   case 27:
-#line 212 "langlisp_yacc.y"
+#line 212 "parser/lisplike/langlisp_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_INT;     }
     break;
 
   case 28:
-#line 213 "langlisp_yacc.y"
+#line 213 "parser/lisplike/langlisp_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_UINT;    }
     break;
 
   case 29:
-#line 214 "langlisp_yacc.y"
+#line 214 "parser/lisplike/langlisp_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_STRING;  }
     break;
 
   case 30:
-#line 215 "langlisp_yacc.y"
+#line 215 "parser/lisplike/langlisp_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_FLOAT;   }
     break;
 
   case 31:
-#line 216 "langlisp_yacc.y"
+#line 216 "parser/lisplike/langlisp_yacc.y"
     { yyval.xtype = XL_TYPE_TYPE_DOUBLE;  }
     break;
 
   case 32:
-#line 220 "langlisp_yacc.y"
+#line 220 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_type_create (yyvsp[0].xtype, XL_TYPE_ARRAY_TYPE_NONE, 0, NULL); }
     break;
 
   case 33:
-#line 221 "langlisp_yacc.y"
+#line 221 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_expr_new (); }
     break;
 
   case 34:
-#line 222 "langlisp_yacc.y"
+#line 222 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_expr_new (); }
     break;
 
   case 35:
-#line 227 "langlisp_yacc.y"
+#line 227 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr =  xl_expr_new_identifier (yyvsp[0].identifier); }
     break;
 
   case 36:
-#line 231 "langlisp_yacc.y"
+#line 231 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_data_string_create (yyvsp[0].val_string);   }
     break;
 
   case 37:
-#line 232 "langlisp_yacc.y"
+#line 232 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_data_integer_create (yyvsp[0].val_int);  }
     break;
 
   case 38:
-#line 233 "langlisp_yacc.y"
+#line 233 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_data_float_create (yyvsp[0].val_float);    }
     break;
 
   case 39:
-#line 234 "langlisp_yacc.y"
+#line 234 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_data_bool_create (TRUE);   }
     break;
 
   case 40:
-#line 235 "langlisp_yacc.y"
+#line 235 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_data_bool_create (FALSE);  }
     break;
 
   case 41:
-#line 243 "langlisp_yacc.y"
+#line 243 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = yyvsp[0].expr; }
     break;
 
   case 42:
-#line 244 "langlisp_yacc.y"
+#line 244 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = yyvsp[0].expr; }
     break;
 
   case 43:
-#line 245 "langlisp_yacc.y"
+#line 245 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = yyvsp[0].expr; }
     break;
 
   case 44:
-#line 246 "langlisp_yacc.y"
+#line 246 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("+", yyvsp[-2].expr, yyvsp[-1].expr); }
     break;
 
   case 45:
-#line 247 "langlisp_yacc.y"
+#line 247 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("*", yyvsp[-2].expr, yyvsp[-1].expr); }
     break;
 
   case 46:
-#line 248 "langlisp_yacc.y"
+#line 248 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("-", yyvsp[-2].expr, yyvsp[-1].expr); }
     break;
 
   case 47:
-#line 249 "langlisp_yacc.y"
+#line 249 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("/", yyvsp[-2].expr, yyvsp[-1].expr); }
     break;
 
   case 48:
-#line 250 "langlisp_yacc.y"
+#line 250 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("<", yyvsp[-2].expr, yyvsp[-1].expr); }
     break;
 
   case 49:
-#line 251 "langlisp_yacc.y"
+#line 251 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 (">", yyvsp[-2].expr, yyvsp[-1].expr); }
     break;
 
   case 50:
-#line 252 "langlisp_yacc.y"
+#line 252 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("[]", yyvsp[-2].expr, yyvsp[-1].expr); }
     break;
 
   case 51:
-#line 253 "langlisp_yacc.y"
+#line 253 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("==", yyvsp[-2].expr, yyvsp[-1].expr); }
     break;
 
   case 52:
-#line 254 "langlisp_yacc.y"
+#line 254 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("<=", yyvsp[-2].expr, yyvsp[-1].expr); }
     break;
 
   case 53:
-#line 255 "langlisp_yacc.y"
+#line 255 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 (">=", yyvsp[-2].expr, yyvsp[-1].expr); }
     break;
 
   case 54:
-#line 256 "langlisp_yacc.y"
+#line 256 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("<>", yyvsp[-2].expr, yyvsp[-1].expr); }
     break;
 
   case 56:
-#line 265 "langlisp_yacc.y"
+#line 265 "parser/lisplike/langlisp_yacc.y"
     { xl_lang_call_add (yyvsp[0].expr); }
     break;
 
   case 57:
-#line 266 "langlisp_yacc.y"
+#line 266 "parser/lisplike/langlisp_yacc.y"
     { xl_lang_call_add (yyvsp[0].expr); }
     break;
 
   case 60:
-#line 284 "langlisp_yacc.y"
+#line 284 "parser/lisplike/langlisp_yacc.y"
     { xl_lang_block_add (yyvsp[0].expr); }
     break;
 
   case 61:
-#line 285 "langlisp_yacc.y"
+#line 285 "parser/lisplike/langlisp_yacc.y"
     { xl_lang_block_add (yyvsp[0].expr); }
     break;
 
   case 62:
-#line 286 "langlisp_yacc.y"
+#line 286 "parser/lisplike/langlisp_yacc.y"
     { xl_lang_block_add (yyvsp[0].expr); }
     break;
 
   case 63:
-#line 295 "langlisp_yacc.y"
+#line 295 "parser/lisplike/langlisp_yacc.y"
     { xl_lang_block_begin (); }
     break;
 
   case 64:
-#line 298 "langlisp_yacc.y"
+#line 298 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_block_end (); }
     break;
 
   case 65:
-#line 302 "langlisp_yacc.y"
+#line 302 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = yyvsp[0].expr; }
     break;
 
   case 66:
-#line 303 "langlisp_yacc.y"
+#line 303 "parser/lisplike/langlisp_yacc.y"
     { xl_lang_block_begin (); }
     break;
 
   case 67:
-#line 303 "langlisp_yacc.y"
+#line 303 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_block_end (); }
     break;
 
   case 68:
-#line 308 "langlisp_yacc.y"
+#line 308 "parser/lisplike/langlisp_yacc.y"
     { xl_lang_call_begin (x_string_get_str (yyvsp[0].expr->identifier)); }
     break;
 
   case 69:
-#line 311 "langlisp_yacc.y"
+#line 311 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_call_end (); }
     break;
 
   case 70:
-#line 316 "langlisp_yacc.y"
+#line 316 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = xl_lang_efnct_create2 ("=", yyvsp[-2].expr, yyvsp[-1].expr); }
     break;
 
   case 71:
-#line 349 "langlisp_yacc.y"
+#line 349 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = NULL; }
     break;
 
   case 72:
-#line 350 "langlisp_yacc.y"
+#line 350 "parser/lisplike/langlisp_yacc.y"
     { yyval.expr = yyvsp[0].expr; }
     break;
 
   case 73:
-#line 358 "langlisp_yacc.y"
+#line 358 "parser/lisplike/langlisp_yacc.y"
     {
       yyval.expr = xl_lang_efnct_create2 ("if", yyvsp[-3].expr, yyvsp[-2].expr); 
       if (yyvsp[-1].expr)
@@ -1751,6 +1751,6 @@ yyreturn:
 }
 
 
-#line 368 "langlisp_yacc.y"
+#line 368 "parser/lisplike/langlisp_yacc.y"
 
 
