@@ -27,8 +27,17 @@
 #include <xstring.h>
 #include <xlexpr.h>
 #include <xlclass.h>
+#include <xlfield.h>
+#include <xlmeth.h>
+#include <xlmain.h>
+#include <xllang.h>
+#include <xloper.h>
 
-XLClass* g_xl_builtin_current_class;
+extern XLClass* g_xl_builtin_current_class;
+extern XString* g_xl_builtin_domain;
+
+#define XL_ERROR printf
+#define XL_ERR_BAD_EXPR   "ERROR('%s'): '%s' expression of bad type\n"
 
 xvoid
 xl_builtin_init ();
@@ -36,10 +45,15 @@ xl_builtin_init ();
 xvoid
 xl_builtin_exit ();
 
-
 /* Declarators
  */
 
+xvoid
+xl_builtin_domain (XLExpr* p_expr);
+
+xvoid
+xl_builtin_using (XLExpr* p_expr);
+
 xvoid
 xl_builtin_fnct (XLExpr* p_expr);
 
@@ -55,18 +69,6 @@ xl_builtin_global (XLExpr* p_expr);
 xvoid
 xl_builtin_const (XLExpr* p_expr);
 
-xvoid
-xl_builtin_class (XLExpr* p_expr);
-
-xvoid
-xl_builtin_prop (XLExpr* p_expr);
-
-xvoid
-xl_builtin_meth (XLExpr* p_expr);
-
-xvoid
-xl_builtin_meth_static (XLExpr* p_expr);
-
 
 /* Class & Objects
  */
@@ -80,102 +82,10 @@ xl_builtin_access (XLExpr* p_expr);
 xvoid
 xl_builtin_invoke (XLExpr* p_expr);
 
-
-/* Assignement
- */
-
-xvoid
-xl_builtin_assign  (XLExpr* p_expr);
-
 xvoid
 xl_builtin_cast  (XLExpr* p_expr);
 
 
-/* Binary
- */
-
-xvoid
-xl_builtin_binary_or (XLExpr* p_expr);
-
-xvoid
-xl_builtin_binary_and (XLExpr* p_expr);
-
-
-/* Logic
- */
-
-xvoid
-xl_builtin_logic_or (XLExpr* p_expr);
-
-xvoid
-xl_builtin_logic_and (XLExpr* p_expr);
-
-/* Mathematics
- */
-
-xvoid
-xl_builtin_add (XLExpr* p_expr);
-
-xvoid
-xl_builtin_sub (XLExpr* p_expr);
-
-xvoid
-xl_builtin_mul (XLExpr* p_expr);
-
-xvoid
-xl_builtin_div (XLExpr* p_expr);
-
-xvoid
-xl_builtin_inc (XLExpr* p_expr);
-
-xvoid
-xl_builtin_dec (XLExpr* p_expr);
-
-
-/* Flow control
- */
-
-xvoid
-xl_builtin_block (XLExpr* p_expr);
-
-xvoid
-xl_builtin_if (XLExpr* p_expr);
-
-xvoid
-xl_builtin_while (XLExpr* p_expr);
-
-xvoid
-xl_builtin_for (XLExpr* p_expr);
-
-xvoid
-xl_builtin_foreach (XLExpr* p_expr);
-
-xvoid
-xl_builtin_return (XLExpr* p_expr);
-
-
-/* Comparaisons
- */
-
-xvoid
-xl_builtin_cmp_l (XLExpr* p_expr);
-
-xvoid
-xl_builtin_cmp_g (XLExpr* p_expr);
-
-xvoid
-xl_builtin_cmp_le (XLExpr* p_expr);
-
-xvoid
-xl_builtin_cmp_ge (XLExpr* p_expr);
-
-xvoid
-xl_builtin_cmp_ne (XLExpr* p_expr);
-
-xvoid
-xl_builtin_cmp_e (XLExpr* p_expr);
-
-
 /* Language control
  */
 
