@@ -36,12 +36,12 @@ xl_data_new (XLType* p_type, xptr p_ref)
   
   if (p_ref)
     {
-      self->ref = TRUE;
+      self->is_ref = TRUE;
       self->raw = p_ref;
       return self;
     }
 
-  self->ref = FALSE;
+  self->is_ref = FALSE;
   self->raw = NULL; 
 
   xl_data_init_data (self);
@@ -49,49 +49,62 @@ xl_data_new (XLType* p_type, xptr p_ref)
   return self;
 }
 
+XLData*
+xl_data_new_simple (XLTypeType simple_type)
+{
+  XLData* self;
+  XLType* type;
+
+  type = xl_type_new (simple_type, XL_TYPE_ARRAY_TYPE_NONE, 0, NULL);
+  self = xl_data_new (type, NULL);
+  x_unref (type);
+
+  return self;
+}
+
+XLData*
+xl_data_new_integer (xint value)
+{
+  XLData* self;
+
+  self = xl_data_new_simple (XL_TYPE_TYPE_UINT);
+  ((XLDataVariant*) self->raw)->vint = value;
+
+  return self;
+}
+
+XLData*
+xl_data_new_boolean (xbool value)
+{
+  XLData* self;
+
+  self = xl_data_new_simple (XL_TYPE_TYPE_UINT);
+  ((XLDataVariant*) self->raw)->vbool = vlaue;
+
+  return self;
+}
+
 xvoid
 xl_data_destroy (XObject* self)
 {
-  XString*        l_string;
-  XLangArray*     l_array;
-  XLangObjectRef* l_objref;
-  xuint           i, l_size;;
+  XString*         l_string;
+  XLDataArray*     l_array;
+  XLDataObject*    l_object;
+  xuint            i, l_size;;
 
-  if (!XL_DATA (self)->ref)
+  if (!XL_DATA (self)->is_ref)
     {
       switch (XL_DATA (self)->type->array_type)
 	{
 	case XL_TYPE_ARRAY_TYPE_NONE:
 	  
-	  switch (XL_DATA (self)->type->type)
-	    {
-	    case XL_TYPE_TYPE_STRING:
-	      l_string = (XString*) (XL_DATA (self)->raw);
-	      x_unref (l_string);
-	      break;
-	    case XL_TYPE_TYPE_OBJECT:
-	      l_objref = ((XLangObjectRef*) XL_DATA (self)->raw);
-	      if (l_objref->obj)
-		{
-		  l_objref->obj->refcount--;
-		  if (l_objref->obj->refcount <= 0)
-		    {
-		      x_unref (l_objref->obj->class);
-		      x_destroy (l_objref->obj->raw);
-		      x_destroy (l_objref->obj);		      
-		    }
-		  }
-	      x_destroy (l_objref);
-	      break;
-	    default:
-	      if (XL_DATA (self)->raw)
-		x_destroy (XL_DATA (self)->raw);
-	    }
+	  xl_datavariant_destroy ((XLDataVariant*) self->raw);
+	  x_destroy (XL_DATA (self)->raw);
 	  break;
 	  
 	case XL_TYPE_ARRAY_TYPE_FIXED:
 	case XL_TYPE_ARRAY_TYPE_DYNAMIC:
-	  l_array = ((XLangArray*) XL_DATA (self)->raw);
+	  l_array = ((XLDataArray*) XL_DATA (self)->raw);
 	  if (l_array)
 	    {
 	      l_size = xl_data_array_get_size (XL_DATA (self));
@@ -115,7 +128,7 @@ xl_data_init_data (XLData* self)
   XLType*      l_type;
   xuint	       i, l_size;    
   xptr         l_ptr;
-  XLangArray*  l_array;
+  XLDataArray* l_array;
   XString*     l_string;
 
   switch (self->type->array_type)
@@ -125,45 +138,45 @@ xl_data_init_data (XLData* self)
       switch (self->type->type)
 	{
 	case XL_TYPE_TYPE_STRING:
-	  if (!self->ref)
+	  if (!self->is_ref)
 	    self->raw = (xptr) x_string_new ();
 	  break;
 
 	case XL_TYPE_TYPE_BOOL:
-	  if (!self->ref)
+	  if (!self->is_ref)
 	    self->raw = x_alloc (sizeof (xbool));
 	  x_access (self->raw, 0, xbool) = FALSE;
 	  break;
 
 	case XL_TYPE_TYPE_CHAR:
 	case XL_TYPE_TYPE_UCHAR:
-	  if (!self->ref)
+	  if (!self->is_ref)
 	    self->raw = x_alloc (sizeof (xuchar));
 	  x_access (self->raw, 0, xuchar) = 0;
 	  break;
 
 	case XL_TYPE_TYPE_SHORT:
 	case XL_TYPE_TYPE_USHORT:
-	  if (!self->ref)
+	  if (!self->is_ref)
 	    self->raw = x_alloc (sizeof (xushort));
 	  x_access (self->raw, 0, xushort) = 0;
 	  break;
       
 	case XL_TYPE_TYPE_INT:
 	case XL_TYPE_TYPE_UINT:
-	  if (!self->ref)
+	  if (!self->is_ref)
 	    self->raw = x_alloc (sizeof (xuint));	  
 	  x_access (self->raw, 0, xuint) = 0;
 	  break;
 
 	case XL_TYPE_TYPE_FLOAT:
-	  if (!self->ref)
+	  if (!self->is_ref)
 	    self->raw = x_alloc (sizeof (xfloat));	  
 	  x_access (self->raw, 0, xfloat) = 0.0;
 	  break;
 
 	case XL_TYPE_TYPE_DOUBLE:
-	  if (!self->ref)
+	  if (!self->is_ref)
 	    self->raw = x_alloc (sizeof (xdouble));
 	  x_access (self->raw, 0, xdouble) = 0.0;
 	  break;
@@ -172,20 +185,18 @@ xl_data_init_data (XLData* self)
 	  l_class = xl_type_get_class (self->type);
 	  if (l_class)
 	    {
-	      if (!self->ref)
-		self->raw = x_alloc (sizeof (XLangObjectRef));
-	      
-	      ((XLangObjectRef*) self->raw)->obj = NULL;	     
+	      if (!self->is_ref)
+		self->raw = x_alloc (sizeof (XLDataObject));
 	    }
 	  break;
 	}
       break;
 
     case XL_TYPE_ARRAY_TYPE_FIXED:
-      if (!self->ref)
-	self->raw = x_alloc (sizeof (XLangArray));
+      if (!self->is_ref)
+	self->raw = x_alloc (sizeof (XLDataArray));
 
-      l_array = (XLangArray*) self->raw;
+      l_array = (XLDataArray*) self->raw;
 
       l_array->size = self->type->array_size;
 
@@ -203,10 +214,10 @@ xl_data_init_data (XLData* self)
       break;
 
     case XL_TYPE_ARRAY_TYPE_DYNAMIC:
-      if (!self->ref)
-	self->raw = x_alloc (sizeof (XLangArray));
+      if (!self->is_ref)
+	self->raw = x_alloc (sizeof (XLDataArray));
 
-      l_array = (XLangArray*) self->raw;
+      l_array = (XLDataArray*) self->raw;
 
       l_array->size = self->type->array_size;
       l_array->data = x_alloc (l_array->size * sizeof (xl_type_get_size (self->type)));
@@ -245,11 +256,11 @@ xl_data_get_raw (XLData* self)
 xvoid
 xl_data_assign (XLData* self, XLData* p_src)
 {
-  XLangObjectRef*  l_objsrc;
-  XLangObjectRef*  l_objdst;
-  XString*         l_text;
-  XLClass*         l_class;
-  xchar            l_str[1000];
+  XLDataObject*  l_objsrc;
+  XLDataObject*  l_objdst;
+  XString*       l_text;
+  XLClass*       l_class;
+  xchar          l_str[1000];
 
   if (!p_src)
     {
@@ -320,16 +331,11 @@ xl_data_assign (XLData* self, XLData* p_src)
 
   if (self->type->type == XL_TYPE_TYPE_OBJECT)
     {
-      l_objdst = ((XLangObjectRef*) self->raw);
-      l_objsrc = ((XLangObjectRef*) p_src->raw);
+      l_objdst = ((XLDataObject*) self->raw);
+      l_objsrc = ((XLDataObject*) p_src->raw);
 
-      if (l_objdst->obj)
-	l_objdst->obj->refcount--;
-
-      l_objdst->obj = l_objsrc->obj;
-
-      if (l_objdst->obj)
-	l_objdst->obj->refcount++;
+      l_objdst->refcount--;
+      l_objdst->refcount++;
     }
 }
 
@@ -359,11 +365,11 @@ xl_data_convert (XLData* self, XLType* p_type)
 XLData*
 xl_data_get_index (XLData* self, xuint p_index)
 {
-  XLangArray* l_array;
-  XLData*     l_data;
-  XLType*     l_type;
-  xptr        l_raw;
-  xuint       l_size;
+  XLDataArray* l_array;
+  XLData*      l_data;
+  XLType*      l_type;
+  xptr         l_raw;
+  xuint        l_size;
 
   switch (self->type->array_type)
     {
@@ -372,7 +378,7 @@ xl_data_get_index (XLData* self, xuint p_index)
       l_type = xl_type_new (self->type->type, XL_TYPE_ARRAY_TYPE_NONE, 0, self->type->classname);
       l_size = xl_type_get_size (l_type);
 
-      l_array = (XLangArray*) self->raw;
+      l_array = (XLDataArray*) self->raw;
       l_raw = l_array->data;
       l_data = xl_data_new (l_type, &x_access (l_raw, (p_index*l_size), xptr));
       x_unref (l_type);
@@ -383,7 +389,7 @@ xl_data_get_index (XLData* self, xuint p_index)
       l_type = xl_type_new (self->type->type, XL_TYPE_ARRAY_TYPE_NONE, 0, self->type->classname);
       l_size = xl_type_get_size (l_type);
 
-      l_array = (XLangArray*) self->raw;
+      l_array = (XLDataArray*) self->raw;
       l_raw = l_array->data;
 
       if (p_index >= 0 && p_index < l_array->size)
@@ -416,7 +422,7 @@ xl_data_array_get_size (XLData* self)
     case XL_TYPE_ARRAY_TYPE_FIXED:
       return self->type->array_size;
     case XL_TYPE_ARRAY_TYPE_DYNAMIC:
-      return ((XLangArray*) self->raw)->size;
+      return ((XLDataArray*) self->raw)->size;
     default:
       return 0;
     }
@@ -425,10 +431,10 @@ xl_data_array_get_size (XLData* self)
 xvoid
 xl_data_array_set_size (XLData* self, xuint p_newsize)
 {
-  XLangArray* l_array;
-  XLData*     l_data;
-  xuint       l_oldsize;
-  xuint       i;
+  XLDataArray* l_array;
+  XLData*      l_data;
+  xuint        l_oldsize;
+  xuint        i;
 
   x_assert (self != NULL);
 
@@ -438,7 +444,7 @@ xl_data_array_set_size (XLData* self, xuint p_newsize)
       printf ("error: unable to resize a fixed array\n");
       break;
     case XL_TYPE_ARRAY_TYPE_DYNAMIC:
-      l_array = (XLangArray*) self->raw;
+      l_array = (XLDataArray*) self->raw;
       l_oldsize = l_array->size;
       l_array->size = p_newsize;
       l_array->data = x_resize (l_array->data, l_array->size * xl_type_get_size (self->type));
@@ -462,17 +468,17 @@ xl_data_array_set_size (XLData* self, xuint p_newsize)
 
 XLData*
 xl_data_get_field (XLData* self, XString* p_fieldname, xbool p_force)
-{
-  XLClass*     l_class;
-  XLType*      l_type;
-  XLData*      l_data;
-  XLField*     l_field;
-  xptr         l_raw;
-  XLangObject* l_obj;
+ {
+  XLClass*      l_class;
+  XLType*       l_type;
+  XLData*       l_data;
+  XLField*      l_field;
+  xptr          l_raw;
+  XLDataObject* l_obj;
 
   if (self->type->type == XL_TYPE_TYPE_OBJECT)
     {
-      l_obj = ((XLangObjectRef*) self->raw)->obj;
+      l_obj = ((XLDataObject*) self->raw);
       if (!l_obj)
 	{
 	  printf ("error: null object\n");
@@ -499,13 +505,12 @@ xl_data_get_field (XLData* self, XString* p_fieldname, xbool p_force)
   switch (self->type->type)
     {
     case XL_TYPE_TYPE_OBJECT:
-      l_obj = ((XLangObjectRef*) self->raw)->obj;
+      l_obj = ((XLDataObject*) self->raw);
       if (!l_obj)
 	{
 	  printf ("warning: uninitialized object\n");
 	  return NULL;
 	}
-      l_raw = l_obj->raw;
       l_data = xl_data_new (l_field->type, ((xuchar*) l_raw) + l_field->index);
       break;
     default:
@@ -537,11 +542,11 @@ xl_data_set_raw (XLData* self, xptr p_raw)
 XLClass*
 xl_data_get_class (XLData* self)
 {
-  XLangObjectRef* l_objref;
+  XLDataObject* l_objref;
 
-  l_objref = ((XLangObjectRef*) self->raw);
-  if (l_objref->obj)
-    return x_addref (XLClass, l_objref->obj->class);
+  l_objref = ((XLDataObject*) self->raw);
+  if (l_objref)
+    return x_addref (XLClass, l_objref->class);
   else
     return NULL;
 }
@@ -549,7 +554,7 @@ xl_data_get_class (XLData* self)
 xvoid
 xl_data_object_new (XLData* self, XLClass* p_class)
 {
-  XLangObjectRef* l_objref;
+  XLDataObject*   l_objref;
   XLField*        l_field;
   XLData*         l_data;
   XLClass*        l_class;
@@ -562,11 +567,10 @@ xl_data_object_new (XLData* self, XLClass* p_class)
 
   xl_class_init_class (p_class);
 
-  l_objref = (XLangObjectRef*) self->raw;
-  l_objref->obj = x_alloc (sizeof (XLangObject));
-  l_objref->obj->refcount = 1;
-  l_objref->obj->class = x_addref (XLClass, p_class);
-  l_objref->obj->raw = x_alloc (xl_class_get_size (p_class));
+  l_objref = (XLDataObject*) self->raw;
+  l_objref = x_alloc (sizeof (XLDataObject));
+  l_objref->refcount = 1;
+  l_objref->class = x_addref (XLClass, p_class);
   
   /* We loop in all fields
    */
@@ -618,3 +622,21 @@ xl_data_object_new (XLData* self, XLClass* p_class)
 
   x_unref (l_name);
 }
+
+xbool
+xl_data_read_integer (XLData* self, xint* value)
+{
+  if (self->type->array_type == XL_TYPE_ARRAY_TYPE_NONE)
+    {
+      if (self->type->type == XL_TYPE_TYPE_SHORT || self->type->type == XL_TYPE_TYPE_USHORT ||
+	  self->type->type == XL_TYPE_TYPE_INT || self->type->type == XL_TYPE_TYPE_UINT)
+	{
+	  *value = x_access (self->raw, 0, xint);
+	  return TRUE;
+	}
+      else
+	return FALSE;
+    }
+  else
+    return FALSE;
+}
