@@ -27,6 +27,11 @@
 #include <xstring.h>
 #include <xltype.h>
 
+#include <xldatastring.h>
+#include <xldataobject.h>
+#include <xldataarray.h>
+#include <xldatavariant.h>
+
 #define XL_DATA(obj) ((XLData*) obj)
 
 struct _XLData
@@ -34,35 +39,22 @@ struct _XLData
   XObject parent;
   
   XLType* type;
-  xbool   ref;
+  xbool   is_ref;
   xptr	  raw;
 };
 
-typedef struct _XLangArray XLangArray;
-struct _XLangArray
-{
-  xuint   size;
-  xptr    data;
-};
-
-typedef struct _XLangObject XLangObject;
-struct _XLangObject
-{
-  XLClass* class;
-  xuint    refcount;
-
-  xptr     raw;
-};
-
-typedef struct _XLangObjectRef XLangObjectRef;
-struct _XLangObjectRef
-{
-  XLangObject* obj;
-};
-
 XLData*
 xl_data_new (XLType* p_type, xptr p_ref);
 
+XLData*
+xl_data_new_simple (XLTypeType simple_type);
+
+XLData*
+xl_data_new_integer (xint value);
+
+XLData*
+xl_data_new_boolean (xbool value);
+
 xvoid
 xl_data_destroy (XObject* self);
 
@@ -120,5 +112,8 @@ xl_data_get_class (XLData* self);
 xvoid
 xl_data_object_new (XLData* self, XLClass* p_class);
 
+xbool
+xl_data_read_integer (XLData* self, xint* value);
+
 #endif
 
