@@ -29,6 +29,8 @@ typedef struct _XLType   XLType;
 typedef struct _XLClass  XLClass;
 typedef struct _XLField  XLField;
 typedef struct _XLMeth   XLMeth;
+typedef struct _XLDomain XLDomain;
+typedef struct _XLGlobal XLGlobal;
 
 #include <xdefs.h>
 #include <xobject.h>
