@@ -290,6 +290,26 @@ xl_expr_set_identifier (XLExpr* self, XString* p_identifier)
   self->identifier = x_addref (XString, p_identifier);
 }
 
+xbool
+xl_expr_read_integer (XLExpr* self, xuint index, xint* value)
+{
+  XLExpr* subexpr;
+  
+  subexpr = XL_EXPR (x_list_get (self->list_expr, index));
+  xl_expr_evaluate (subexpr);
+
+  if (xl_data_read_integer (subexpr->data, value))
+    {
+      x_unref (subexpr);
+      return TRUE;
+    }
+  else
+    {
+      x_unref (subexpr);
+      return FALSE;
+    }
+}
+
 xuint nb_tab = 0;
 
 xvoid
