@@ -27,7 +27,7 @@
 #include <xltype.h>
 #include <xlmain.h>
 #include <xllang.h>
-#include <xlcompiler.h>
+#include <compiler/xlcompiler.h>
 #include <stdarg.h>
 
 xptr (* xl_fnct_direct_void) ();
