@@ -23,9 +23,9 @@
 #include <xldata.h>
 #include <xltype.h>
 #include <xlexpr.h>
-#include <xllanglisp.h>
-#include <xllangbasic.h>
-#include <xllangc.h>
+#include <parser/lisplike/xllanglisp.h>
+#include <parser/basiclike/xllangbasic.h>
+#include <parser/clike/xllangc.h>
 #include <xllangpkg.h>
 
 XLExpr*  g_lang_expr = NULL;
@@ -48,6 +48,8 @@ XString* g_lang_filename = NULL;
 
 XLExpr*  g_lang_class = NULL;
 
+XString* g_lang_classname = NULL;
+
 XLLang*
 xl_lang_new (xstr p_filename)
 {
@@ -74,6 +76,18 @@ xl_lang_new (xstr p_filename)
   return NULL;
 }
 
+xvoid
+xl_lang_warning (xstr msg)
+{
+  printf ("warning: %s\n", msg);
+}
+
+xvoid
+xl_lang_error (xstr msg)
+{
+  printf ("%s:%d: error: %s\n", x_string_get_str (g_lang_filename), g_lang_line, msg);
+}
+
 XLExpr*
 xl_lang_type_create (XLTypeType p_type, XLTypeArrayType p_array, xuint p_size, XString* p_class)
 {
@@ -98,10 +112,13 @@ xl_lang_decl_add (XLExpr* p_expr)
 xvoid
 xl_lang_class_create (XLExpr* p_identifier, XLExpr* p_parent)
 {
-  XLExpr* l_parent;
+  XLExpr*  l_parent;
 
   g_lang_class = xl_expr_new_fnct ("@class");
 
+  x_unref (g_lang_classname);
+  g_lang_classname = x_addref (XString, p_identifier->identifier);
+
   xl_expr_add (g_lang_class, p_identifier);
   x_unref (p_identifier);
 
@@ -127,6 +144,18 @@ xl_lang_class_add (XLExpr* p_expr)
   x_unref (p_expr);
 }
 
+xbool
+xl_lang_class_check (xstr p_classname)
+{
+  if (g_lang_classname)
+    if (x_string_cmp_str (g_lang_classname, p_classname)==0)
+      return TRUE;
+    else
+      return FALSE;
+  else
+    return FALSE;
+}
+
 XLExpr*
 xl_lang_data_string_create (xstr p_text)
 {
@@ -155,6 +184,26 @@ xl_lang_data_string_create (xstr p_text)
   return l_expr;
 }
 
+XLExpr*
+xl_lang_data_char_create (xchar p_char)
+{
+  XLExpr* l_expr;
+  XLType* l_type;
+  XLData* l_data;
+
+  l_type = xl_type_new (XL_TYPE_TYPE_CHAR, XL_TYPE_ARRAY_TYPE_NONE, 0, NULL);
+  l_data = xl_data_new (l_type, NULL);
+  x_access (xl_data_get_raw (l_data), 0, xchar) = p_char;
+  
+  l_expr = xl_expr_new ();
+  xl_expr_set_data (l_expr, l_data);
+
+  x_unref (l_type);
+  x_unref (l_data);
+
+  return l_expr;
+}
+
 XLExpr*
 xl_lang_data_integer_create (xint p_int)
 {
