@@ -29,6 +29,7 @@ extern XLExpr*   g_lang_expr;
 extern xuint     g_lang_line;
 extern xuint     g_lang_nberr;
 extern XString*  g_lang_filename;
+extern XString*  g_lang_classname;
 
 #define XL_LANG(obj) ((XLLang*) obj)
 
@@ -43,6 +44,12 @@ struct _XLLang
 XLLang*
 xl_lang_new (xstr p_filename);
 
+xvoid
+xl_lang_warning (xstr warning);
+
+xvoid
+xl_lang_error (xstr error);
+
 XLExpr*
 xl_lang_type_create (XLTypeType p_type, XLTypeArrayType p_array, xuint p_size, XString* p_class);
 
@@ -55,12 +62,18 @@ xl_lang_class_create (XLExpr* p_identifier, XLExpr* p_parent);
 XLExpr*
 xl_lang_class_finish ();
 
+xbool
+xl_lang_class_check (xstr p_classname);
+
 xvoid
 xl_lang_class_add (XLExpr* p_expr);
 
 XLExpr*
 xl_lang_data_string_create (xstr p_text);
 
+XLExpr*
+xl_lang_data_char_create (xchar p_char);
+
 XLExpr*
 xl_lang_data_integer_create (xint p_int);
 
