@@ -59,7 +59,7 @@ xl_main_exit ()
 XLMain*
 xl_main_new ()
 {
-  XLMain *self;
+  XLMain*  self;
 
   self = x_new (XLMain);
   x_object_init_object (X_OBJECT (self), xl_main_destroy);
@@ -69,10 +69,10 @@ xl_main_new ()
   /* HashTable support (see above)
    */
 
-  self->hash_local = NULL;
-  self->hash_global = x_hash_table_new (x_string_hash, x_string_equal);
-  self->hash_functions = x_hash_table_new (x_string_hash, x_string_equal);
-  self->hash_classes = x_hash_table_new (x_string_hash, x_string_equal);
+  self->locals = NULL;
+  self->globals = x_hash_table_new (x_string_hash, x_string_equal);
+  self->functions = x_hash_table_new (x_string_hash, x_string_equal);
+  self->classes = x_hash_table_new (x_string_hash, x_string_equal);
 
   self->list_stack = x_list_new ();
   
@@ -87,10 +87,10 @@ xl_main_destroy (XObject* self)
   /* HashTable support (see above)
    */
 
-  x_unref (XL_MAIN (self)->hash_global);
-  x_unref (XL_MAIN (self)->hash_local);
-  x_unref (XL_MAIN (self)->hash_functions);
-  x_unref (XL_MAIN (self)->hash_classes);
+  x_unref (XL_MAIN (self)->globals);
+  x_unref (XL_MAIN (self)->locals);
+  x_unref (XL_MAIN (self)->functions);
+  x_unref (XL_MAIN (self)->classes);
 
   x_destroy (self);
 }
@@ -110,7 +110,7 @@ xl_main_add_fnct_builtin (XLMain* self, xstr p_name, XLFnctBuiltin p_builtin)
   /* HashTable support (see above)
    */
 
-  x_hash_table_insert(self->hash_functions, (void*)l_fnct->name, X_OBJECT(l_fnct));
+  x_hash_table_insert(self->functions, (void*)l_fnct->name, X_OBJECT(l_fnct));
 
   x_unref (l_fnct);
   x_unref (l_name);
@@ -131,7 +131,7 @@ xl_main_add_fnct_native (XLMain* self, xstr p_name, xptr p_native)
   /* HashTable support (see above)
    */
 
-  x_hash_table_insert(self->hash_functions, (void*)l_fnct->name, X_OBJECT(l_fnct));
+  x_hash_table_insert(self->functions, (void*)l_fnct->name, X_OBJECT(l_fnct));
 
   x_unref (l_fnct);
   x_unref (l_name);
@@ -154,7 +154,7 @@ xl_main_add_fnct_expr (XLMain* self, xstr p_name, XLExpr* p_expr)
   /* HashTable support (see above)
    */
 
-  x_hash_table_insert (self->hash_functions, (void*) l_fnct->name, X_OBJECT(l_fnct));
+  x_hash_table_insert (self->functions, (void*) l_fnct->name, X_OBJECT(l_fnct));
 
   x_unref (l_fnct);
   x_unref (l_name);
@@ -177,7 +177,7 @@ xl_main_add_fnct_proto (XLMain* self, xstr p_name)
   /* HashTable support (see above)
    */
 
-  x_hash_table_insert(self->hash_functions, (void*) l_fnct->name, X_OBJECT(l_fnct));
+  x_hash_table_insert(self->functions, (void*) l_fnct->name, X_OBJECT(l_fnct));
 
   x_unref (l_fnct);
   x_unref (l_name);
@@ -191,7 +191,7 @@ xl_main_get_fnct (XLMain* self, XString* p_name)
   /* HashTable support (see above)
    */
 
-  return x_hash_table_find (self->hash_functions, (void*) p_name);
+  return x_hash_table_find (self->functions, (void*) p_name);
 }
 
 xvoid
@@ -200,10 +200,10 @@ xl_main_add_var (XLMain* self, XLVar* p_var, xbool p_global)
   /* HashTable support (see above)
    */
 
-  if ((self->hash_local) && !p_global)
-    x_hash_table_insert (self->hash_local, (xvoid*) p_var->name, X_OBJECT(p_var));
+  if ((self->locals) && !p_global)
+    x_hash_table_insert (self->locals, (xvoid*) p_var->name, X_OBJECT(p_var));
   else
-    x_hash_table_insert (self->hash_global, (xvoid*) p_var->name, X_OBJECT(p_var));
+    x_hash_table_insert (self->globals, (xvoid*) p_var->name, X_OBJECT(p_var));
 }
 
 XLVar*
@@ -214,14 +214,14 @@ xl_main_get_var (XLMain* self, XString* p_name)
 
   XLVar* l_var;
 
-  if (self->hash_local) 
+  if (self->locals) 
     {
-      l_var = x_hash_table_find (self->hash_local, p_name);
+      l_var = x_hash_table_find (self->locals, p_name);
       if (l_var)
 	return l_var;
     }
 
-  return x_hash_table_find (self->hash_global, p_name);
+  return x_hash_table_find (self->globals, p_name);
 }
 
 xvoid
@@ -230,7 +230,7 @@ xl_main_add_class (XLMain* self, XLClass* p_class)
   /* HashTable support (see above)
    */
 
-  x_hash_table_insert (self->hash_classes, (xvoid*) p_class->name, X_OBJECT(p_class));
+  x_hash_table_insert (self->classes, (xvoid*) p_class->name, X_OBJECT(p_class));
 }
 
 XLClass*
@@ -239,7 +239,7 @@ xl_main_get_class (XLMain* self, XString* p_name)
   /* HashTable support (see above)
    */
 
-  return x_hash_table_find (self->hash_classes, p_name);
+  return x_hash_table_find (self->classes, p_name);
 }
 
 XHashTable*
@@ -250,8 +250,8 @@ xl_main_fnct_enter (XLMain* self, XLFnct* p_fnct)
 
   XHashTable* l_hash;
   
-  l_hash = self->hash_local;
-  self->hash_local = x_hash_table_new (x_string_hash, x_string_equal);
+  l_hash = self->locals;
+  self->locals = x_hash_table_new (x_string_hash, x_string_equal);
   
   return l_hash;
 }
@@ -262,8 +262,8 @@ xl_main_fnct_leave (XLMain* self, XHashTable* p_hash)
   /* HashTable support (see above)
    */
 
-  x_unref (self->hash_local);
-  self->hash_local = p_hash;
+  x_unref (self->locals);
+  self->locals = p_hash;
 }
 
 xvoid
@@ -271,6 +271,18 @@ xl_main_print (XString* p_msg)
 {
 }
 
+xvoid
+xl_main_warning (xstr msg)
+{
+  printf ("error: %s\n", msg);
+}
+
+xvoid
+xl_main_error (xstr msg)
+{
+  printf ("error: %s\n", msg);
+}
+
 int
 xl_main_main (int argc, char** argv)
 {
@@ -359,7 +371,7 @@ xl_main_main (int argc, char** argv)
 	      /* HashTable support (see above)
 	       */
 	      
-	      x_hash_table_foreach (g_xl_main_global->hash_functions, (UserFunc) xl_fnct_compile, NULL);
+	      x_hash_table_foreach (g_xl_main_global->functions, (UserFunc) xl_fnct_compile, NULL);
 	    }
 	  
 	  l_name = x_string_new ();
