@@ -45,11 +45,11 @@ struct _XLMain
 
   /* HashTable support (see above)
    */
-  
-  XHashTable* hash_global;
-  XHashTable* hash_local;
-  XHashTable* hash_functions;
-  XHashTable* hash_classes;
+
+  XHashTable* globals;
+  XHashTable* locals;
+  XHashTable* functions;
+  XHashTable* classes;
 
   XList*  list_stack;
 
@@ -106,6 +106,12 @@ xl_main_fnct_enter (XLMain* self, XLFnct* p_fnct);
 xvoid
 xl_main_fnct_leave (XLMain* self, XHashTable* p_hash);
 
+xvoid
+xl_main_warning (xstr msg);
+
+xvoid
+xl_main_error (xstr msg);
+
 int
 xl_main_main (int argc, char** argv);
 
