@@ -95,12 +95,12 @@ xl_type_get_size (XLType* self)
 	case XL_TYPE_TYPE_DOUBLE:
 	  return sizeof (xdouble);
 	case XL_TYPE_TYPE_OBJECT:
-	  return sizeof (XLangObjectRef);
+	  return sizeof (XLDataObject);
 	}
     case XL_TYPE_ARRAY_TYPE_FIXED:
-      return sizeof (XLangArray);
+      return sizeof (XLDataArray);
     case XL_TYPE_ARRAY_TYPE_DYNAMIC:
-      return sizeof (XLangArray);
+      return sizeof (XLDataArray);
     }
 
   printf ("unmanaged typed\n");
