@@ -19,8 +19,12 @@
 /* These files are distributed at http://www.freesoftware.fsf.org/xlang/
  */
 
+#include <config.h>
 #include <scr/xscr.h>
+
+#ifdef HAVE_OS_WIN32
 #include <windows.h>
+#endif
 
 xvoid
 x_scr_init ()
@@ -40,19 +44,22 @@ x_scr_clear ()
 xvoid
 x_scr_write (XString* data)
 {
+#ifdef HAVE_OS_WIN32
   DWORD dw;
-
   WriteConsole (GetStdHandle (STD_OUTPUT_HANDLE), x_string_get_str (data), data->size, &dw, NULL);
+#endif
 }
 
 xvoid
 x_scr_gotoxy (xuint x, xuint y)
 {
+#ifdef HAVE_OS_WIN32
   COORD coord;
 
   coord.X = x;
   coord.Y = y;
   SetConsoleCursorPosition (GetStdHandle (STD_OUTPUT_HANDLE), coord);
+#endif
 }
 
 xuint
